@@ -34,13 +34,18 @@ class SplunkAlertAutomator():
 
     """
 
-    def __init__(self, splunk_uri: str, username: str, password: str, splunk_app: str = None) -> None:
+    def __init__(self, splunk_uri: str, username: str, password: str, splunk_app: str = None, owner:str='nobody') -> None:
 
         self.splunk_uri = splunk_uri
         self.username = username
         self.password = password
         self.splunk_app = splunk_app
 
+        if owner:
+            self.owner=owner
+        else:
+            self.owner=username
+
         return
 
     def __create_alert(self, alert_configs):
@@ -48,7 +53,7 @@ class SplunkAlertAutomator():
         params = (
             ('output_mode', 'json'),
         )
-        response = requests.post(f'{self.splunk_uri}:8089/servicesNS/{self.username}/{self.splunk_app}/saved/searches/',
+        response = requests.post(f'{self.splunk_uri}:8089/servicesNS/{self.owner}/{self.splunk_app}/saved/searches/',
                                  data=alert_configs,
                                  verify=False,
                                  params=params,
@@ -58,7 +63,7 @@ class SplunkAlertAutomator():
 
     def __delete_alert(self, alert_name:str):
 
-        response = requests.delete(f'{self.splunk_uri}:8089/servicesNS/{self.username}/{self.splunk_app}/saved/searches/{alert_name}',
+        response = requests.delete(f'{self.splunk_uri}:8089/servicesNS/{self.owner}/{self.splunk_app}/saved/searches/{alert_name}',
                                    verify=False,
                                    auth=(self.username, self.password))
         return response
@@ -67,7 +72,7 @@ class SplunkAlertAutomator():
         params = (
             ('output_mode', 'json'),
         )
-        response = requests.get(f'{self.splunk_uri}:8089/servicesNS/{self.username}/{self.splunk_app}/saved/searches/{alert_name}',
+        response = requests.get(f'{self.splunk_uri}:8089/servicesNS/{self.owner}/{self.splunk_app}/saved/searches/{alert_name}',
                                    verify=False,
                                    params=params,
                                    auth=(self.username, self.password))
@@ -100,7 +105,7 @@ class SplunkAlertAutomator():
 
     def update_alert(self, alert_name, alert_update_config):
 
-        response = requests.post(f'{self.splunk_uri}:8089/servicesNS/{self.username}/{self.splunk_app}/saved/searches/{alert_name}',
+        response = requests.post(f'{self.splunk_uri}:8089/servicesNS/{self.owner}/{self.splunk_app}/saved/searches/{alert_name}',
                                  verify=False,
                                  data=alert_update_config,
                                  auth=(self.username, self.password))
@@ -181,7 +186,7 @@ class SplunkAlertAutomator():
         data = {
             'search': splunk_search, 'output_mode': 'json'
         }
-        response = requests.post(f'{self.splunk_uri}:8089/servicesNS/{self.username}/search/search/jobs/export',
+        response = requests.post(f'{self.splunk_uri}:8089/servicesNS/{self.owner}/search/search/jobs/export',
                                  data=data,
                                  verify=False,
                                  auth=(self.username, self.password))
@@ -210,7 +215,7 @@ class SplunkAlertAutomator():
 
     def get_alert_acl(self, alert_name):
 
-        response = requests.get(f'{self.splunk_uri}:8089/servicesNS/{self.username}/{self.splunk_app}/saved/searches/{alert_name}/acl',
+        response = requests.get(f'{self.splunk_uri}:8089/servicesNS/{self.owner}/{self.splunk_app}/saved/searches/{alert_name}/acl',
                                  verify=False,
 
                                  auth=(self.username, self.password))
@@ -220,7 +225,7 @@ class SplunkAlertAutomator():
     def change_alert_acl(self, alert_name, alert_acl_dict):
 
         
-        response = requests.post(f'{self.splunk_uri}:8089/servicesNS/{self.username}/{self.splunk_app}/saved/searches/{alert_name}/acl',
+        response = requests.post(f'{self.splunk_uri}:8089/servicesNS/{self.owner}/{self.splunk_app}/saved/searches/{alert_name}/acl',
                                  verify=False,
                                  data=alert_acl_dict,
                                  auth=(self.username, self.password))
@@ -275,7 +280,7 @@ class SplunkDashboardAutomator():
     def delete_dashboard_list(self,dashboard_list:list):
         response_list=[]
         for dashboard_name in dashboard_list:
-            reponse_list.append(self.delete_dashboard(dashboard_name=dashboard_name))
+            response_list.append(self.delete_dashboard(dashboard_name=dashboard_name))
         return response_list
 
     def __get_dashboard(self, dashboard_name: str):
@@ -453,7 +458,7 @@ class SplunkAutomator():
         self.alerts=SplunkAlertAutomator(splunk_uri, username, password, splunk_app)
         self.dashboards=SplunkDashboardAutomator(splunk_uri, username, password, splunk_app)
 
-    def __repr__():
+    def __repr__(self):
         pass
         
 
